summaryrefslogtreecommitdiff
path: root/flist.c
diff options
context:
space:
mode:
authorWayne Davison <wayned@samba.org>2008-08-02 10:20:51 -0700
committerWayne Davison <wayned@samba.org>2008-08-02 10:20:51 -0700
commite34ad4e925293ff222bb4fe47b010153fa9f30ab (patch)
tree4dc87a736bf9946de68c3a3f4ae2013d29a89901 /flist.c
parentf303b749f2843433c9acd8218a4b9096d0d1bb8d (diff)
downloadrsync-e34ad4e925293ff222bb4fe47b010153fa9f30ab.tar.gz
Refer to the symlink's contents as "symlink data", not "symlink name".
Diffstat (limited to 'flist.c')
-rw-r--r--flist.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/flist.c b/flist.c
index 41035ff2..061d1be6 100644
--- a/flist.c
+++ b/flist.c
@@ -839,7 +839,7 @@ static struct file_struct *recv_file_entry(struct file_list *flist,
}
#ifdef ICONV_OPTION
/* We don't know how much extra room we need to convert
* the as-yet-unread symlink name when converting it,
* so let's hope that a double-size buffer is plenty. */
if (sender_symlink_iconv)
linkname_len = linkname_len * 2 + 1;
@@ -991,7 +991,7 @@ static struct file_struct *recv_file_entry(struct file_list *flist,
alloc_len = linkname_len;
linkname_len /= 2; /* (linkname_len-1) / 2 for odd values. */
/* Read the symlink name into the end of our double-sized
* buffer and then convert it into the right spot. */
INIT_XBUF(inbuf, bp + alloc_len - linkname_len,
linkname_len - 1, (size_t)-1);
@@ -1001,7 +1001,7 @@ static struct file_struct *recv_file_entry(struct file_list *flist,
if (iconvbufs(ic_recv, &inbuf, &outbuf, 0) < 0) {
io_error |= IOERR_GENERAL;
rprintf(FERROR_XFER,
- "[%s] cannot convert symlink name for: %s (%s)\n",
+ "[%s] cannot convert symlink data for: %s (%s)\n",
who_am_i(), full_fname(thisname), strerror(errno));
bp = (char*)file->basename;
*bp++ = '\0';
@@ -1430,7 +1430,7 @@ static struct file_struct *send_file_name(int f, struct file_list *flist,
io_error |= IOERR_GENERAL;
f_name(file, fbuf);
rprintf(FERROR_XFER,
- "[%s] cannot convert symlink name for: %s (%s)\n",
+ "[%s] cannot convert symlink data for: %s (%s)\n",
who_am_i(), full_fname(fbuf), strerror(errno));
return NULL;
}
@@ -839,7 +839,7 @@ static struct file_struct *recv_file_entry(struct file_list *flist,
#ifdef ICONV_OPTION
/* We don't know how much extra room we need to convert
- * the as-yet-unread symlink name when converting it,
+ * the as-yet-unread symlink data when converting it,
* so let's hope that a double-size buffer is plenty. */
if (sender_symlink_iconv)
@@ -991,7 +991,7 @@ static struct file_struct *recv_file_entry(struct file_list *flist,
alloc_len = linkname_len;
linkname_len /= 2; /* (linkname_len-1) / 2 for odd values. */
- /* Read the symlink name into the end of our double-sized
+ /* Read the symlink data into the end of our double-sized
* buffer and then convert it into the right spot. */
INIT_XBUF(inbuf, bp + alloc_len - linkname_len,